@@ -1,4 +1,4 @@
-package Zonemaster v1.0.2;
+package Zonemaster v1.0.3;
 
 use 5.014002;
 use Moose;
@@ -150,7 +150,7 @@ sub start_time_now {
 sub reset {
     Zonemaster::Logger->start_time_now();
     Zonemaster::Nameserver->empty_cache();
-    $logger->clear_history();
+    $logger->clear_history() if $logger;
     Zonemaster::Recursor->clear_cache();
 
     return;
@@ -164,6 +164,10 @@ Zonemaster - A tool to check the quality of a DNS zone
 
     my @results = Zonemaster->test_zone('iis.se')
 
+=head1 INTRODUCTION
+
+This manual describes the main L<Zonemaster> module. If what you're after is documentation on the Zonemaster test engine as a whole, see L<Zonemaster::Overview>.
+
 =head1 METHODS
 
 =over
