@@ -34,6 +34,8 @@ has 'dns'   => ( is => 'ro', isa => 'Net::LDNS',                     lazy_build
 has 'cache' => ( is => 'ro', isa => 'Zonemaster::Nameserver::Cache', lazy_build => 1 );
 has 'times' => ( is => 'ro', isa => 'ArrayRef',                      default    => sub { [] } );
 
+has 'source_address' => ( is => 'ro', isa => 'Maybe[Str]', lazy => 1, default => sub {return Zonemaster->config->resolver_source} );
+
 has 'fake_delegations' => ( is => 'ro', isa => 'HashRef', default => sub { {} } );
 has 'fake_ds'          => ( is => 'ro', isa => 'HashRef', default => sub { {} } );
 
@@ -74,6 +76,10 @@ sub _build_dns {
         $res->$flag( $defaults{$flag} );
     }
 
+    if ( $self->source_address ) {
+        $res->source($self->source_address);
+    }
+
     return $res;
 }
 
@@ -455,6 +461,8 @@ sub axfr {
 sub empty_cache {
     %object_cache = ();
 
+    Zonemaster::Nameserver::Cache::empty_cache();
+
     return;
 }
 
@@ -472,6 +480,19 @@ Zonemaster::Nameserver - object representing a DNS nameserver
     my $ns = Zonemaster::Nameserver->new({ name => 'ns.nic.se', address => '212.247.7.228' });
     my $p = $ns->query('www.iis.se', 'AAAA');
 
+=head1 DESCRIPTION
+
+This is a very central object in the L<Zonemaster> framework. All DNS
+communications with the outside world pass through here, so we can do
+things like synthezising and recording traffic. All the objects are
+also unique per name/IP pair, and creating a new one with an already
+existing pair will return the existing object instead of creating a
+new one. Queries and their responses are cached by IP address, so that
+a specific query will only be sent once to each address (even if there
+are multiple objects for that address with different names).
+
+Class methods on this class allows saving and loading cache contents.
+
 =head1 ATTRIBUTES
 
 =over
@@ -486,7 +507,7 @@ A L<Net::IP::XS> object holding the nameserver's address.
 
 =item dns
 
-The L<Net::LDNS::Resolver> object used to actually send and recieve DNS queries.
+The L<Net::LDNS> object used to actually send and recieve DNS queries.
 
 =item cache
 
@@ -498,7 +519,30 @@ A reference to a list with elapsed time values for the queries made through this
 
 =back
 
-=head1 METHODS
+=head1 CLASS METHODS
+
+=over
+
+=item save($filename)
+
+Save the entire object cache to the given filename, using the
+byte-order-independent Storable format.
+
+=item restore($filename)
+
+Replace the entire object cache with the contents of the named file.
+
+=item all_known_nameservers()
+
+Class method that returns a list of all nameserver objects in the global cache.
+
+=item empty_cache()
+
+Remove all cached nameserver objects and queries.
+
+=back
+
+=head1 INSTANCE METHODS
 
 =over
 
@@ -560,14 +604,6 @@ Returns a string representation of the object. Normally this is just the name an
 
 Used for overloading comparison operators.
 
-=item save($filename)
-
-Save the entire object cache to the given filename, using the byte-order-independent Storable format.
-
-=item restore($filename)
-
-Replace the entire object cache with the contents of the named file.
-
 =item sum_time()
 
 Returns the total time spent sending queries and waiting for responses.
@@ -592,10 +628,6 @@ Returns the median query time.
 
 Returns the standard deviation for the whole set of query times.
 
-=item all_known_nameservers()
-
-Class method that returns a list of all nameserver objects in the global cache.
-
 =item add_fake_delegation($domain,$data)
 
 Adds fake delegation information to this specific nameserver object. Takes the
@@ -617,10 +649,6 @@ argument. To continue getting more RRs, the callback must return a true value.
 If it returns a true value, the AXFR will be aborted. See L<Net::LDNS::axfr>
 for more details.
 
-=item empty_cache()
-
-Remove all entries from the object cache.
-
 =back
 
 =cut
