@@ -371,8 +371,8 @@ sub policy {
         "NO_COMMON_KEYTAGS"            => "ERROR",
         "NO_DNSKEY"                    => "WARNING",
         "NO_DS"                        => "NOTICE",
-        "NO_KEYS_OR_NO_SIGS"           => "ERROR",
-        "NO_KEYS_OR_NO_SIGS_OR_NO_SOA" => "ERROR",
+        "NO_KEYS_OR_NO_SIGS"           => "DEBUG",
+        "NO_KEYS_OR_NO_SIGS_OR_NO_SOA" => "DEBUG",
         "NO_NSEC3PARAM"                => "DEBUG",
         "NSEC3_SIG_VERIFY_ERROR"       => "ERROR",
         "NSEC3_COVERS"                 => "DEBUG",
@@ -392,7 +392,7 @@ sub policy {
         "SOA_SIGNATURE_OK"             => "DEBUG",
         "SOA_SIGNED"                   => "DEBUG",
         "TOO_MANY_ITERATIONS"          => "WARNING",
-        "DELEGATION_NOT_SIGNED"        => "ERROR",
+        "DELEGATION_NOT_SIGNED"        => "NOTICE",
         "DELEGATION_SIGNED"            => "INFO",
     };
 } ## end sub policy
@@ -879,6 +879,9 @@ sub dnssec08 {
             $ok = $sig->keytag;
         }
         else {
+            if ($sig->algorithm == 12 and $msg =~ /Unknown cryptographic algorithm/) {
+                $msg = 'no GOST support';
+            }
             push @results,
               info(
                 DNSKEY_SIGNATURE_NOT_OK => {
@@ -949,6 +952,9 @@ sub dnssec09 {
             $ok = $sig->keytag;
         }
         else {
+            if ($sig->algorithm == 12 and $msg =~ /Unknown cryptographic algorithm/) {
+                $msg = 'no GOST support';
+            }
             push @results,
               info(
                 SOA_SIGNATURE_NOT_OK => {
@@ -1025,6 +1031,9 @@ sub dnssec10 {
                         $ok = 1;
                     }
                     else {
+                        if ($sig->algorithm == 12 and $msg =~ /Unknown cryptographic algorithm/) {
+                            $msg = 'no GOST support';
+                        }
                         push @results,
                           info(
                             NSEC_SIG_VERIFY_ERROR => {
@@ -1086,6 +1095,9 @@ sub dnssec10 {
                         $ok = 1;
                     }
                     else {
+                        if ($sig->algorithm == 12 and $msg =~ /Unknown cryptographic algorithm/) {
+                            $msg = 'no GOST support';
+                        }
                         push @results,
                           info(
                             NSEC3_SIG_VERIFY_ERROR => {
@@ -1165,6 +1177,9 @@ sub dnssec11 {
                             $pass = $tag;
                         }
                         else {
+                            if ($sig->algorithm == 12 and $msg =~ /Unknown cryptographic algorithm/) {
+                                $msg = 'no GOST support';
+                            }
                             push @fail, "signature: $msg" ;
                         }
                     }
