@@ -1,4 +1,4 @@
-package Zonemaster::Test::Nameserver v0.1.0;
+package Zonemaster::Test::Nameserver v1.0.1;
 
 use 5.14.2;
 use strict;
@@ -19,12 +19,12 @@ sub all {
     my ( $class, $zone ) = @_;
     my @results;
 
-    push @results, $class->nameserver01( $zone );
-    push @results, $class->nameserver02( $zone );
-    push @results, $class->nameserver03( $zone );
-    push @results, $class->nameserver04( $zone );
-    push @results, $class->nameserver05( $zone );
-    push @results, $class->nameserver06( $zone );
+    push @results, $class->nameserver01( $zone ) if Zonemaster->config->should_run('nameserver01');
+    push @results, $class->nameserver02( $zone ) if Zonemaster->config->should_run('nameserver02');
+    push @results, $class->nameserver03( $zone ) if Zonemaster->config->should_run('nameserver03');
+    push @results, $class->nameserver04( $zone ) if Zonemaster->config->should_run('nameserver04');
+    push @results, $class->nameserver05( $zone ) if Zonemaster->config->should_run('nameserver05');
+    push @results, $class->nameserver06( $zone ) if Zonemaster->config->should_run('nameserver06');
 
     return @results;
 }
@@ -271,7 +271,7 @@ sub nameserver04 {
 
         my $p = $local_ns->query( $zone->name, q{SOA} );
         if ( $p ) {
-            if ( $p->answerfrom and ($local_ns->address->short ne Net::IP::XS->new($p->answerfrom)->short ) ) {
+            if ( $p->answerfrom and ( $local_ns->address->short ne Net::IP::XS->new( $p->answerfrom )->short ) ) {
                 push @results,
                   info(
                     DIFFERENT_SOURCE_IP => {
@@ -380,9 +380,9 @@ sub nameserver05 {
 sub nameserver06 {
     my ( $class, $zone ) = @_;
     my @results;
-    my @all_nsnames = uniq map { lc($_->string) } @{ Zonemaster::TestMethods->method2( $zone ) },
+    my @all_nsnames = uniq map { lc( $_->string ) } @{ Zonemaster::TestMethods->method2( $zone ) },
       @{ Zonemaster::TestMethods->method3( $zone ) };
-    my @all_nsnames_with_ip = uniq map { lc($_->name->string) } @{ Zonemaster::TestMethods->method4( $zone ) },
+    my @all_nsnames_with_ip = uniq map { lc( $_->name->string ) } @{ Zonemaster::TestMethods->method4( $zone ) },
       @{ Zonemaster::TestMethods->method5( $zone ) };
     my @all_nsnames_without_ip;
     my %diff;
