@@ -1,4 +1,4 @@
-package Zonemaster::Test::Syntax v1.0.0;
+package Zonemaster::Test::Syntax v1.0.1;
 
 use 5.14.2;
 use strict;
@@ -25,26 +25,26 @@ sub all {
     my ( $class, $zone ) = @_;
     my @results;
 
-    push @results, $class->syntax01( $zone->name );
-    push @results, $class->syntax02( $zone->name );
-    push @results, $class->syntax03( $zone->name );
+    push @results, $class->syntax01( $zone->name ) if Zonemaster->config->should_run('syntax01');
+    push @results, $class->syntax02( $zone->name ) if Zonemaster->config->should_run('syntax02');
+    push @results, $class->syntax03( $zone->name ) if Zonemaster->config->should_run('syntax03');
 
     if ( any { $_->tag eq q{ONLY_ALLOWED_CHARS} } @results ) {
 
         foreach my $local_nsname ( uniq map { $_->string } @{ Zonemaster::TestMethods->method2( $zone ) },
             @{ Zonemaster::TestMethods->method3( $zone ) } )
         {
-            push @results, $class->syntax04( $local_nsname );
+            push @results, $class->syntax04( $local_nsname ) if Zonemaster->config->should_run('syntax04');
         }
 
-        push @results, $class->syntax05( $zone );
+        push @results, $class->syntax05( $zone ) if Zonemaster->config->should_run('syntax05');
 
         if ( none { $_->tag eq q{NO_RESPONSE_SOA_QUERY} } @results ) {
-            push @results, $class->syntax06( $zone );
-            push @results, $class->syntax07( $zone );
+            push @results, $class->syntax06( $zone ) if Zonemaster->config->should_run('syntax06');
+            push @results, $class->syntax07( $zone ) if Zonemaster->config->should_run('syntax07');
         }
 
-        push @results, $class->syntax08( $zone );
+        push @results, $class->syntax08( $zone ) if Zonemaster->config->should_run('syntax08');
 
     }
 
