@@ -1,4 +1,4 @@
-package Zonemaster::Test::Zone v1.0.0;
+package Zonemaster::Test::Zone v1.0.1;
 
 use 5.14.2;
 use strict;
@@ -21,22 +21,22 @@ sub all {
     my ( $class, $zone ) = @_;
     my @results;
 
-    push @results, $class->zone01( $zone );
+    push @results, $class->zone01( $zone ) if Zonemaster->config->should_run('zone01');
     if ( none { $_->tag eq q{NO_RESPONSE_SOA_QUERY} } @results ) {
 
-        push @results, $class->zone02( $zone );
-        push @results, $class->zone03( $zone );
-        push @results, $class->zone04( $zone );
-        push @results, $class->zone05( $zone );
-        push @results, $class->zone06( $zone );
+        push @results, $class->zone02( $zone ) if Zonemaster->config->should_run('zone02');
+        push @results, $class->zone03( $zone ) if Zonemaster->config->should_run('zone03');
+        push @results, $class->zone04( $zone ) if Zonemaster->config->should_run('zone04');
+        push @results, $class->zone05( $zone ) if Zonemaster->config->should_run('zone05');
+        push @results, $class->zone06( $zone ) if Zonemaster->config->should_run('zone06');
         if ( none { $_->tag eq q{MNAME_RECORD_DOES_NOT_EXIST} } @results ) {
-            push @results, $class->zone07( $zone );
+            push @results, $class->zone07( $zone ) if Zonemaster->config->should_run('zone07');
         }
     }
     if ( none { $_->tag eq q{MNAME_RECORD_DOES_NOT_EXIST} } @results ) {
-        push @results, $class->zone08( $zone );
+        push @results, $class->zone08( $zone ) if Zonemaster->config->should_run('zone08');
         if ( none { $_->tag eq q{NO_RESPONSE_MX_QUERY} } @results ) {
-            push @results, $class->zone09( $zone );
+            push @results, $class->zone09( $zone ) if Zonemaster->config->should_run('zone09');
         }
     }
 
@@ -55,7 +55,8 @@ sub metadata {
             qw(
               MNAME_RECORD_DOES_NOT_EXIST
               MNAME_NOT_AUTHORITATIVE
-              MNAME_NO_RESPONSE MNAME_NOT_IN_GLUE
+              MNAME_NO_RESPONSE
+              MNAME_NOT_IN_GLUE
               MNAME_IS_AUTHORITATIVE
               NO_RESPONSE_SOA_QUERY
               )
@@ -185,7 +186,13 @@ sub zone01 {
         }
         else {
             foreach my $ip_address ( Zonemaster::Recursor->get_addresses_for( $soa_mname ) ) {
+
                 my $ns = Zonemaster::Nameserver->new( { name => $soa_mname, address => $ip_address->short } );
+
+                if ( _is_ip_version_disabled($ns) ) {
+                    next;
+                }
+
                 my $p_soa = $ns->query( $zone->name, q{SOA} );
                 if ( $p_soa and $p_soa->rcode eq q{NOERROR} ) {
                     if ( not $p_soa->aa ) {
@@ -544,13 +551,7 @@ sub _retrieve_record_from_zone {
     # Return response from the first authoritative server that gives one
     foreach my $ns ( @{ Zonemaster::TestMethods->method5( $zone ) } ) {
 
-        if ( not Zonemaster->config->ipv4_ok and $ns->address->version == $IP_VERSION_4 ) {
-            Zonemaster->logger->add( SKIP_IPV4_DISABLED => { ns => "$ns" } );
-            next;
-        }
-
-        if ( not Zonemaster->config->ipv6_ok and $ns->address->version == $IP_VERSION_6 ) {
-            Zonemaster->logger->add( SKIP_IPV6_DISABLED => { ns => "$ns" } );
+        if ( _is_ip_version_disabled($ns) ) {
             next;
         }
 
@@ -564,6 +565,22 @@ sub _retrieve_record_from_zone {
     return;
 } ## end sub _retrieve_record_from_zone
 
+sub _is_ip_version_disabled {
+    my $ns = shift;
+
+    if ( not Zonemaster->config->ipv4_ok and $ns->address->version == $IP_VERSION_4 ) {
+        Zonemaster->logger->add( SKIP_IPV4_DISABLED => { ns => "$ns" } );
+        return 1;
+    }
+
+    if ( not Zonemaster->config->ipv6_ok and $ns->address->version == $IP_VERSION_6 ) {
+        Zonemaster->logger->add( SKIP_IPV6_DISABLED => { ns => "$ns" } );
+        return 1;
+    }
+
+    return;
+}
+
 1;
 
 =head1 NAME
